import clsx from "clsx";
import { Metadata, Viewport } from "next";
import { Inter } from "next/font/google";
import Script from "next/script";

import AppProvider from "./components/AppProvider";
import { ThemeProvider } from "./components/ThemeProvider";
import { Config } from "./config";
import "./globals.css";

const font = Inter({ subsets: ["latin-ext"], weight: "500" });

export const viewport: Viewport = {
  themeColor: "#3B82F6",
};

export const metadata: Metadata = {
  metadataBase: new URL(Config.siteUrl),
  title: {
    template: Config.siteName + " - %s",
    default: Config.siteName,
  },
  description: Config.description,
  openGraph: {
    title: Config.siteName,
    description: Config.description,
    url: Config.siteUrl,
    locale: "en_US",
    type: "website",
  },
};

export default function RootLayout({
  children,
}: {
  children: React.ReactNode;
}) {
  return (
    <html lang="en">
      <Script
        id="plausible"
        data-domain="ssr.fascinated.cc"
        src="https://analytics.fascinated.cc/js/script.js"
        defer
      />

      <body className={clsx(font.className, "text-primary")}>
        <ThemeProvider
          storageKey="ssr-theme"
          attribute="class"
          defaultTheme="dark"
          enableSystem
        >
          <AppProvider>{children}</AppProvider>
        </ThemeProvider>
      </body>
    </html>
  );
}
